%global pkgname django-reversion
Name:           python-django-reversion
Version:        2.0.13
Release:        2%{?dist}
Summary:        Version control extension for the Django web framework

Group:          Development/Languages
License:        BSD
URL:            http://github.com/etianen/django-reversion
Source0:        https://github.com/etianen/django-reversion/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildArch:      noarch
Provides:       %{pkgname} = %{version}-%{release}
Obsoletes:      %{pkgname} < 1.6.2-1

%description
Reversion is an extension to the Django web framework that provides
comprehensive version control facilities.

Features:
* Roll back to any point in a model's history - an unlimited undo facility!
* Recover deleted models - never lose data again!
* Admin integration for maximum usability.
* Group related changes into revisions that can be rolled back in a single
  transaction.
* Automatically save a new version whenever your model changes using Django's
  flexible signalling framework.
* Automate your revision management with easy-to-use middleware.

Reversion can be easily added to your existing Django project with a minimum
of code changes.

%package -n python3-%{pkgname}
Summary:        Version control extension for the Django web framework
BuildRequires:  python3-devel
Requires:       python3-django
%{?python_provide:%python_provide python3-%{pkgname}}

Obsoletes:   python-%{pkgname} < 2.0.13-1
Obsoletes:   python2-%{pkgname} < 2.0.13-1

%description -n python3-%{pkgname}
Reversion is an extension to the Django web framework that provides
comprehensive version control facilities.

Features:
* Roll back to any point in a model's history - an unlimited undo facility!
* Recover deleted models - never lose data again!
* Admin integration for maximum usability.
* Group related changes into revisions that can be rolled back in a single
  transaction.
* Automatically save a new version whenever your model changes using Django's
  flexible signalling framework.
* Automate your revision management with easy-to-use middleware.

Reversion can be easily added to your existing Django project with a minimum
of code changes.


%prep
%autosetup -n %{pkgname}-%{version}

%build
%py3_build


%install
%py3_install

# Language files; not under /usr/share, need to be handled manually
(cd $RPM_BUILD_ROOT && find . -name 'django*.mo') | %{__sed} -e 's|^.||' | %{__sed} -e \
  's:\(.*/locale/\)\([^/_]\+\)\(.*\.mo$\):%lang(\2) \1\2\3:' \
  >> %{name}.lang


find $RPM_BUILD_ROOT -name "*.po" | xargs rm -f


%files -n python3-%{pkgname} -f %{name}.lang
%doc README.rst
%license LICENSE
%dir %{python3_sitelib}/reversion
%{python3_sitelib}/reversion/*.py*
%{python3_sitelib}/reversion/__pycache__
%{python3_sitelib}/reversion/management/
%{python3_sitelib}/reversion/templates/
%{python3_sitelib}/reversion/migrations/
%{python3_sitelib}/django_reversion-%{version}-py?.?.egg-info

%changelog
* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.13-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jan 31 2018 Matthias Runge <mrunge@redhat.com> - 2.0.13-1
- update to 2.0.13
- drop Python2 subpackage for https://fedoraproject.org/wiki/Changes/Django20

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 2.0.0-4
- Rebuild for Python 3.6

* Sun Jul 31 2016 Petr Viktorin <pviktori@redhat.com> - 2.0.0-3
- Fix Python sitelib directories

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.0-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Mon Jun 13 2016 Matthias Runge <mrunge@redhat.com> - 2.0.0-1
- update to 2.0 (rhbz#1103194)

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Jan 02 2014 Matthias Runge <mrunge@redhat.com> - 1.8.0-1
- update to 1.8.0 (rhbz#1027767)

* Tue Aug 13 2013 Matthias Runge <mrunge@redhat.com> - 1.7.1-1
- update to 1.7.1 (rhbz#979597)

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Mar 06 2013 Matthias Runge <mrunge@redhat.com> - 1.7-1
- update to upstream version 1.7

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Dec 13 2012 Matthias Runge <mrunge@redhat.com> - 1-6.5-1
- update to upstream version 1.6.5 (rhbz#886552)

* Wed Oct 31 2012 Matthias Runge <mrunge@redhat.com> - 1.6.4-1
- update to upstream version 1.6.4

* Mon Aug 06 2012 Matthias Runge <mrunge@matthias-runge.de> - 1.6.2-1
- updated to upstream release 1.6.2
- package renamed to python-django-reversion

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Apr 10 2012 Luca Botti <lucabotti@fedoraproject.orf> 1.6.0-1
- Updated to 1.6.0

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Nov 14 2010 Luca Botti <lucabotti@fedoraproject.org> 1.3.2-2
- Fixed locale handling

* Fri Nov 12 2010 Luca Botti <lucabotti@fedoraproject.org> 1.3.2-1
- Update to 1.3.2

* Tue Sep 29 2009 Luca Botti <lucabotti@fedoraproject.org> 1.1.2-2
- Fixed Spec File

* Fri Aug 21 2009 Luca Botti <lucabotti@fedoraproject.org> 1.1.2-1
- Update to 1.1.2 upstream release

* Fri Jul 17 2009 Tim Niemueller <timn@fedoraproject.org> 1.1.1
- Initial RPM release
